@@ -382,10 +382,15 @@ func dupArg(m dsl.Matcher) {
 		Report(`suspicious method call with the same argument and receiver`)
 
 	m.Match(`copy($x, $x)`,
+		`cmp.Compare($x, $x)`,
+		`maps.Equal($x, $x)`,
+		`math.Dim($x, $x)`,
 		`math.Max($x, $x)`,
 		`math.Min($x, $x)`,
 		`reflect.Copy($x, $x)`,
 		`reflect.DeepEqual($x, $x)`,
+		`slices.Compare($x, $x)`,
+		`slices.Equal($x, $x)`,
 		`strings.Contains($x, $x)`,
 		`strings.Compare($x, $x)`,
 		`strings.EqualFold($x, $x)`,
@@ -658,24 +663,6 @@ func timeExprSimplify(m dsl.Matcher) {
 		Report(`use $t.UnixMicro() instead of $$`)
 }
 
-//doc:summary Detects Before/After call of time.Time that can be simplified
-//doc:tags    style experimental
-//doc:before  !t.Before(tt)
-//doc:after   t.After(tt)
-func timeCmpSimplify(m dsl.Matcher) {
-	isTime := func(v dsl.Var) bool {
-		return v.Type.Is(`time.Time`) || v.Type.Is(`*time.Time`)
-	}
-
-	m.Match(`!$t.Before($tt)`).
-		Where(isTime(m["t"])).
-		Suggest("$t.After($tt)")
-
-	m.Match(`!$t.After($tt)`).
-		Where(isTime(m["t"])).
-		Suggest("$t.Before($tt)")
-}
-
 //doc:summary Detects exposed methods from sync.Mutex and sync.RWMutex
 //doc:tags    style experimental
 //doc:before  type Foo struct{ ...; sync.Mutex; ... }
@@ -746,7 +733,7 @@ func emptyDecl(m dsl.Matcher) {
 //doc:summary Detects suspicious formatting strings usage
 //doc:tags    diagnostic experimental
 //doc:before  fmt.Errorf(msg)
-//doc:after   fmt.Errorf("%s", msg)
+//doc:after   errors.New(msg) or fmt.Errorf("%s", msg)
 func dynamicFmtString(m dsl.Matcher) {
 	m.Match(`fmt.Errorf($f)`).
 		Where(!m["f"].Const).
@@ -804,3 +791,19 @@ func badSyncOnceFunc(m dsl.Matcher) {
 		Report("possible sync.OnceFunc misuse, consider to assign sync.OnceFunc($x) to a variable").
 		Where(m.GoVersion().GreaterEqThan("1.21"))
 }
+
+//doc:summary Detects bytes.Repeat with 0 value
+//doc:tags    performance
+//doc:before  bytes.Repeat([]byte{0}, x)
+//doc:after   make([]byte, x)
+func zeroByteRepeat(m dsl.Matcher) {
+	m.Match(`bytes.Repeat([]byte{0}, $x)`).
+		Report("avoid bytes.Repeat([]byte{0}, $x); consider using make([]byte, $x) instead").
+		Suggest(`make([]byte, $x)`)
+
+	// Rule 2: const identifier with value 0
+	m.Match(`bytes.Repeat([]byte{$x}, $n)`).
+		Where(m["x"].Const && m["x"].Value.Int() == 0).
+		Report("avoid bytes.Repeat with a const 0; use make([]byte, $n) instead").
+		Suggest(`make([]byte, $n)`)
+}
